
# Class: FileResourceContainer


A container of paths and descriptions

URI: [https://w3id.org/neat/FileResourceContainer](https://w3id.org/neat/FileResourceContainer)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[FileResource]<files%200..*-++[FileResourceContainer],[GraphDataConfiguration]++-%20source_data%200..1>[FileResourceContainer],[GraphDataConfiguration],[FileResource])](https://yuml.me/diagram/nofunky;dir:TB/class/[FileResource]<files%200..*-++[FileResourceContainer],[GraphDataConfiguration]++-%20source_data%200..1>[FileResourceContainer],[GraphDataConfiguration],[FileResource])

## Referenced by Class

 *  **None** *[➞source_data](graphDataConfiguration__source_data.md)*  <sub>0..1</sub>  **[FileResourceContainer](FileResourceContainer.md)**

## Attributes


### Own

 * [➞files](fileResourceContainer__files.md)  <sub>0..\*</sub>
     * Range: [FileResource](FileResource.md)
